@@ -114,8 +114,6 @@ public:
    */
   static void JoinAllSubprocesses();
 
-  static bool PreallocatedProcessReady();
-
   /**
    * Get or create a content process for:
    * 1. browser iframe
@@ -129,21 +127,16 @@ public:
                              ContentParent* aOpener = nullptr,
                              bool aLargeAllocationProcess = false);
 
-  /**
-   * Create a subprocess suitable for use as a preallocated app process.
-   */
-  static already_AddRefed<ContentParent> PreallocateAppProcess();
-
   /**
    * Get or create a content process for the given TabContext.  aFrameElement
    * should be the frame/iframe element with which this process will
    * associated.
    */
   static TabParent*
-  CreateBrowserOrApp(const TabContext& aContext,
-                     Element* aFrameElement,
-                     ContentParent* aOpenerContentParent,
-                     bool aFreshProcess = false);
+  CreateBrowser(const TabContext& aContext,
+                Element* aFrameElement,
+                ContentParent* aOpenerContentParent,
+                bool aFreshProcess = false);
 
   static void GetAll(nsTArray<ContentParent*>& aArray);
 
@@ -231,7 +224,6 @@ public:
                                       const hal::ProcessPriority& aPriority,
                                       const TabId& aOpenerTabId,
                                       ContentParentId* aCpId,
-                                      bool* aIsForApp,
                                       bool* aIsForBrowser,
                                       TabId* aTabId) override;
 
@@ -323,8 +315,6 @@ public:
 
   bool IsAlive() const;
 
-  virtual bool IsForApp() const override;
-
   virtual bool IsForBrowser() const override
   {
     return mIsForBrowser;
@@ -357,10 +347,6 @@ public:
 
   ContentParentId ChildID() const override { return mChildID; }
 
-  const nsString& AppManifestURL() const { return mAppManifestURL; }
-
-  bool IsPreallocated() const;
-
   /**
    * Get a user-friendly name for this ContentParent.  We make no guarantees
    * about this name: It might not be unique, apps can spoof special names,
@@ -546,8 +532,7 @@ protected:
   void OnCompositorUnexpectedShutdown() override;
 
 private:
-  static nsDataHashtable<nsStringHashKey, ContentParent*> *sAppContentParents;
-  static nsTArray<ContentParent*>* sNonAppContentParents;
+  static nsTArray<ContentParent*>* sBrowserContentParents;
   static nsTArray<ContentParent*>* sLargeAllocationContentParents;
   static nsTArray<ContentParent*>* sPrivateContent;
   static StaticAutoPtr<LinkedList<ContentParent> > sContentParents;
@@ -555,15 +540,6 @@ private:
   static void JoinProcessesIOThread(const nsTArray<ContentParent*>* aProcesses,
                                     Monitor* aMonitor, bool* aDone);
 
-  // Take the preallocated process and transform it into a "real" app process,
-  // for the specified manifest URL.  If there is no preallocated process (or
-  // if it's dead), create a new one and set aTookPreAllocated to false.
-  static already_AddRefed<ContentParent>
-  GetNewOrPreallocatedAppProcess(mozIApplication* aApp,
-                                 hal::ProcessPriority aInitialPriority,
-                                 ContentParent* aOpener,
-                                 /*out*/ bool* aTookPreAllocated = nullptr);
-
   static hal::ProcessPriority GetInitialProcessPriority(Element* aFrameElement);
 
   static ContentBridgeParent* CreateContentBridgeParent(const TabContext& aContext,
@@ -579,18 +555,13 @@ private:
       const IPCTabContext& context,
       const uint32_t& chromeFlags,
       const ContentParentId& aCpId,
-      const bool& aIsForApp,
       const bool& aIsForBrowser) override;
   using PContentParent::SendPTestShellConstructor;
 
   FORWARD_SHMEM_ALLOCATOR_TO(PContentParent)
 
-  // No more than one of !!aApp, aIsForBrowser, and aIsForPreallocated may be
-  // true.
-  ContentParent(mozIApplication* aApp,
-                ContentParent* aOpener,
-                bool aIsForBrowser,
-                bool aIsForPreallocated);
+  ContentParent(ContentParent* aOpener,
+                bool aIsForBrowser);
 
   // The common initialization for the constructors.
   void InitializeMembers();
@@ -610,7 +581,7 @@ private:
 
   // Some information could be sent to content very early, it
   // should be send from this function. This function should only be
-  // called after the process has been transformed to app or browser.
+  // called after the process has been transformed to browser.
   void ForwardKnownInfo();
 
   // Set the child process's priority and then check whether the child is
@@ -619,15 +590,6 @@ private:
   // unlikely that the process will be killed after this point.
   bool SetPriorityAndCheckIsAlive(hal::ProcessPriority aPriority);
 
-  // Transform a pre-allocated app process into a "real" app
-  // process, for the specified manifest URL.
-  void TransformPreallocatedIntoApp(ContentParent* aOpener,
-                                    const nsAString& aAppManifestURL);
-
-  // Transform a pre-allocated app process into a browser process. If this
-  // returns false, the child process has died.
-  void TransformPreallocatedIntoBrowser(ContentParent* aOpener);
-
   /**
    * Mark this ContentParent as dead for the purposes of Get*().
    * This method is idempotent.
@@ -688,7 +650,6 @@ private:
                                  ProcessId aOtherProcess) override;
 
   virtual bool RecvGetProcessAttributes(ContentParentId* aCpId,
-                                        bool* aIsForApp,
                                         bool* aIsForBrowser) override;
 
   virtual bool
@@ -713,7 +674,6 @@ private:
                                               const IPCTabContext& aContext,
                                               const uint32_t& aChromeFlags,
                                               const ContentParentId& aCpId,
-                                              const bool& aIsForApp,
                                               const bool& aIsForBrowser) override;
 
   virtual bool DeallocPBrowserParent(PBrowserParent* frame) override;
@@ -912,8 +872,6 @@ private:
 
   virtual bool RecvPrivateDocShellsExist(const bool& aExist) override;
 
-  virtual bool RecvFirstIdle() override;
-
   virtual bool RecvAudioChannelChangeDefVolChannel(const int32_t& aChannel,
                                                    const bool& aHidden) override;
 
@@ -1049,17 +1007,8 @@ private:
   ContentParentId mChildID;
   int32_t mGeolocationWatchID;
 
-  nsString mAppManifestURL;
-
   nsCString mKillHardAnnotation;
 
-  /**
-   * We cache mAppName instead of looking it up using mAppManifestURL when we
-   * need it because it turns out that getting an app from the apps service is
-   * expensive.
-   */
-  nsString mAppName;
-
   // After we initiate shutdown, we also start a timer to ensure
   // that even content processes that are 100% blocked (say from
   // SIGSTOP), are still killed eventually.  This task enforces that
@@ -1075,7 +1024,7 @@ private:
   // through.
   bool mIsAlive;
 
-  // True only the if process is already a browser or app or has
+  // True only the if process is already a browser or has
   // been transformed into one.
   bool mMetamorphosed;
 
