@@ -41,7 +41,6 @@ class nsDocumentFragment;
 class nsIDOMKeyEvent;
 class nsITransferable;
 class nsIClipboard;
-class nsILinkHandler;
 class nsTableWrapperFrame;
 class nsIDOMRange;
 class nsRange;
@@ -1079,7 +1078,8 @@ protected:
   void AddMouseClickListener(nsIDOMElement* aElement);
   void RemoveMouseClickListener(nsIDOMElement* aElement);
 
-  nsCOMPtr<nsILinkHandler> mLinkHandler;
+  bool mDisabledLinkHandling = false;
+  bool mOldLinkHandlingEnabled = false;
 
 public:
   friend class HTMLEditorEventListener;
