@@ -52,7 +52,7 @@
 #define JS_DESCR_SLOT_ARRAYPROTO         6  // Lazily created prototype for arrays
 #define JS_DESCR_SLOT_TRACE_LIST         7  // List of references for use in tracing
 
-// Slots on scalars, references, and SIMD objects
+// Slots on scalars and references
 #define JS_DESCR_SLOT_TYPE               8  // Type code
 
 // Slots on array descriptors
@@ -74,7 +74,6 @@
 #define JS_TYPEREPR_REFERENCE_KIND      2
 #define JS_TYPEREPR_STRUCT_KIND         3
 #define JS_TYPEREPR_ARRAY_KIND          4
-#define JS_TYPEREPR_SIMD_KIND           5
 
 // These constants are for use exclusively in JS code. In C++ code,
 // prefer Scalar::Int8 etc, which allows you to write a switch which will
@@ -90,10 +89,6 @@
 #define JS_SCALARTYPEREPR_UINT8_CLAMPED 8
 #define JS_SCALARTYPEREPR_BIGINT64      9
 #define JS_SCALARTYPEREPR_BIGUINT64     10
-#define JS_SCALARTYPEREPR_FLOAT32X4     13
-#define JS_SCALARTYPEREPR_INT8X16       14
-#define JS_SCALARTYPEREPR_INT16X8       15
-#define JS_SCALARTYPEREPR_INT32X4       16
 
 // These constants are for use exclusively in JS code. In C++ code,
 // prefer ReferenceTypeRepresentation::TYPE_ANY etc, which allows
@@ -103,20 +98,4 @@
 #define JS_REFERENCETYPEREPR_OBJECT     1
 #define JS_REFERENCETYPEREPR_STRING     2
 
-// These constants are for use exclusively in JS code. In C++ code, prefer
-// SimdType::Int32x4 etc, since that allows you to write a switch which will
-// receive a warning if you omit a case.
-#define JS_SIMDTYPEREPR_INT8X16         0
-#define JS_SIMDTYPEREPR_INT16X8         1
-#define JS_SIMDTYPEREPR_INT32X4         2
-#define JS_SIMDTYPEREPR_UINT8X16        3
-#define JS_SIMDTYPEREPR_UINT16X8        4
-#define JS_SIMDTYPEREPR_UINT32X4        5
-#define JS_SIMDTYPEREPR_FLOAT32X4       6
-#define JS_SIMDTYPEREPR_FLOAT64X2       7
-#define JS_SIMDTYPEREPR_BOOL8X16        8
-#define JS_SIMDTYPEREPR_BOOL16X8        9
-#define JS_SIMDTYPEREPR_BOOL32X4       10
-#define JS_SIMDTYPEREPR_BOOL64X2       11
-
 #endif
