@@ -45,14 +45,6 @@ class LIRGeneratorNone : public LIRGeneratorShared
     void lowerForMulInt64(LMulI64*, MMul*, MDefinition*, MDefinition* v = nullptr) { MOZ_CRASH(); }
     template <typename T>
     void lowerForShiftInt64(T, MDefinition*, MDefinition*, MDefinition* v = nullptr) { MOZ_CRASH(); }
-    void lowerForCompIx4(LSimdBinaryCompIx4* ins, MSimdBinaryComp* mir,
-                         MDefinition* lhs, MDefinition* rhs) {
-        MOZ_CRASH();
-    }
-    void lowerForCompFx4(LSimdBinaryCompFx4* ins, MSimdBinaryComp* mir,
-                         MDefinition* lhs, MDefinition* rhs) {
-        MOZ_CRASH();
-    }
     void lowerForBitAndAndBranch(LBitAndAndBranch*, MInstruction*,
                                  MDefinition*, MDefinition*) {
         MOZ_CRASH();
@@ -94,14 +86,7 @@ class LIRGeneratorNone : public LIRGeneratorShared
 
     LTableSwitch* newLTableSwitch(LAllocation, LDefinition, MTableSwitch*) { MOZ_CRASH(); }
     LTableSwitchV* newLTableSwitchV(MTableSwitch*) { MOZ_CRASH(); }
-    void visitSimdSelect(MSimdSelect* ins) { MOZ_CRASH(); }
-    void visitSimdSplat(MSimdSplat* ins) { MOZ_CRASH(); }
-    void visitSimdSwizzle(MSimdSwizzle* ins) { MOZ_CRASH(); }
-    void visitSimdShuffle(MSimdShuffle* ins) { MOZ_CRASH(); }
-    void visitSimdValueX4(MSimdValueX4* lir) { MOZ_CRASH(); }
     void visitSubstr(MSubstr*) { MOZ_CRASH(); }
-    void visitSimdBinaryArith(js::jit::MSimdBinaryArith*) { MOZ_CRASH(); }
-    void visitSimdBinarySaturating(MSimdBinarySaturating* ins) { MOZ_CRASH(); }
     void visitRandom(js::jit::MRandom*) { MOZ_CRASH(); }
     void visitCopySign(js::jit::MCopySign*) { MOZ_CRASH(); }
     void visitWasmTruncateToInt64(MWasmTruncateToInt64*) { MOZ_CRASH(); }
