@@ -20,10 +20,23 @@ function test()
   printBugNumber(BUGNUMBER);
   printStatus (summary);
 
-  expect = '1';
+  function f(x)
+  {
+    var y = 1;
+    if (Math)
+      function x() { }
+    if (Math)
+      function y() { }
+    return [x, y];
+  }
 
-  function g(x) { if (1) function x() {} return x; }
-  print(actual = g(1) + '');
+  var r = f(0);
+
+  if (typeof(r[0]) != "number")
+    actual += "Bad r[0]";
+
+  if (typeof(r[1]) != "function")
+    throw "Bad r[1]";
 
   reportCompare(expect, actual, summary);
 
