@@ -4,21 +4,21 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch07/7.6/7.6.1/7.6.1-2-10.js
- * @description Allow reserved words as property names by dot operator assignment, verified with hasOwnProperty: in, try, class
+ * @path ch07/7.6/7.6.1/7.6.1-3-9.js
+ * @description Allow reserved words as property names by index assignment,verified with hasOwnProperty: if, throw, delete
  */
 
 
 function testcase() {
-        var tokenCodes = {};
-        tokenCodes.in = 0;
-        tokenCodes.try = 1;
-        tokenCodes.class = 2;
+        var tokenCodes  = {};
+        tokenCodes['if'] = 0;
+        tokenCodes['throw'] = 1;
+        tokenCodes['delete'] = 2;
         var arr = [
-            'in', 
-            'try',
-            'class'
-        ];
+            'if',
+            'throw',
+            'delete'
+            ];
         for(var p in tokenCodes) {       
             for(var p1 in arr) {                
                 if(arr[p1] === p) {
