@@ -4,20 +4,21 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch11/11.13/11.13.2/11.13.2-6-2-s.js
- * @description Strict Mode - SyntaxError is thrown if the identifier eval appear as the LeftHandSideExpression of a Compound Assignment operator(/=)
+ * @path ch11/11.4/11.4.1/11.4.1-5-a-8-s.js
+ * @description Strict Mode - SyntaxError is thrown when deleting a function object
  * @onlyStrict
  */
 
 
 function testcase() {
         "use strict";
-        var blah = eval;
+        var funObj = function () { };
+
         try {
-            eval("eval /= 20;");
+            eval("delete funObj;");
             return false;
         } catch (e) {
-            return e instanceof SyntaxError && blah === eval;
+            return e instanceof SyntaxError;
         }
     }
 runTestCase(testcase);
