@@ -4,8 +4,8 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch14/14.1/14.1-11-s.js
- * @description comments may preceed 'use strict' directive
+ * @path ch14/14.1/14.1-7-s.js
+ * @description 'use strict' directive - not recognized if upper case
  * @noStrict
  */
 
@@ -14,11 +14,8 @@ function testcase() {
 
   function foo()
   {
-     // comment
-     /* comment */ "use strict";
-
-   return(this === undefined);
-
+    'Use Strict';
+     return (this !== undefined);
   }
 
   return foo.call(undefined);
