@@ -35,7 +35,7 @@
 #include "nsViewManager.h"
 #include "mozilla/RestyleManager.h"
 #include "SurfaceCacheUtils.h"
-#include "nsCSSRuleProcessor.h"
+#include "nsCSSRuleUtils.h"
 #include "nsRuleNode.h"
 #include "gfxPlatform.h"
 #include "nsCSSRules.h"
@@ -1336,6 +1336,30 @@ nsPresContext::ScreenSizeInchesForFontInflation(bool* aChanged)
   return deviceSizeInches;
 }
 
+// CheckOverflow() is only called on viewport elements (roots and <body> elements, see
+// GetPropagatedScrollStylesForViewport() below).
+// if this ever changes, we need to pass a bool here to indicate whether we are a root/<body> or not,
+// and adjust logic as-necessary.
+// XXX: this only checks overflow-x; it's unclear whether viewport checks truly only need to be
+// checked for y-scrolling, or if the same should apply for x-scrolling. It's certainly the common
+// case for sites specifying `clip` on whole-doc elements.
+//
+// Logic breakdown:
+// https://www.w3.org/TR/2025/WD-css-overflow-3-20251007/#overflow-propagation
+// "user agents must instead apply the overflow-* values of the first [visible html/body] child
+//  element to the viewport. The element from which the value is propagated must then have a
+//  used overflow value of `visible`." AND
+// "If `visible` is applied to the viewport, it must be interpreted as `auto`.
+//  If `clip` is applied to the viewport, it must be interpreted as `hidden`."
+// This is a lot of unnecessary juggling in the spec, but goes like this:
+// 1. Webmaster sets overflow-x to `clip` on root doc or <body>
+// 2. Spec says this should now apply to the viewport, not the element, triggering special handling (4)
+// 3. The other axis must now be set to `visible` instead of `unset` (so far, so good, consistent behavior)
+//    `visible` is an "unscrollable property" which would mandate ScrollStyles(hidden, hidden) here.
+// 4. **However**, because it's the viewport, overflow-y must be changed **again** to `auto`
+// So if unspecified, the spec says `unset` (unscrollable because clip) -> `visible` (unscrollable) ->
+// `auto` (scrollable) if propagated to the viewport (but not any other element where it remains unscrollable).
+// See Issue #2583
 static bool
 CheckOverflow(const nsStyleDisplay* aDisplay, ScrollStyles* aStyles)
 {
@@ -1354,7 +1378,8 @@ CheckOverflow(const nsStyleDisplay* aDisplay, ScrollStyles* aStyles)
 
   if (aDisplay->mOverflowX == NS_STYLE_OVERFLOW_CLIP) {
     *aStyles = ScrollStyles(NS_STYLE_OVERFLOW_HIDDEN,
-                               NS_STYLE_OVERFLOW_HIDDEN, aDisplay);
+                            NS_STYLE_OVERFLOW_AUTO,
+                            aDisplay);
   } else {
     *aStyles = ScrollStyles(aDisplay);
   }
@@ -1652,13 +1677,13 @@ nsPresContext::ThemeChangedInternal()
   }
 
   // This will force the system metrics to be generated the next time they're used
-  nsCSSRuleProcessor::FreeSystemMetrics();
+  nsCSSRuleUtils::FreeSystemMetrics();
 
   // Changes to system metrics can change media queries on them, or
   // :-moz-system-metric selectors (which requires eRestyle_Subtree).
   // Changes in theme can change system colors (whose changes are
   // properly reflected in computed style data), system fonts (whose
-  // changes are not), and -moz-appearance (whose changes likewise are
+  // changes are not), and appearance (whose changes likewise are
   // not), so we need to reflow.
   MediaFeatureValuesChanged(eRestyle_Subtree, NS_STYLE_HINT_REFLOW);
 
@@ -1693,7 +1718,7 @@ nsPresContext::SysColorChangedInternal()
   }
 
   // Invalidate cached '-moz-windows-accent-color-applies' media query:
-  nsCSSRuleProcessor::FreeSystemMetrics();
+  nsCSSRuleUtils::FreeSystemMetrics();
 
   // Reset default background and foreground colors for the document since
   // they may be using system colors
