@@ -536,7 +536,10 @@ CreateAndPaintMaskSurface(const PaintFramesParams& aParams,
   }
 
   RefPtr<DrawTarget> maskDT =
-      ctx.GetDrawTarget()->CreateSimilarDrawTarget(maskSurfaceRect.Size(),
+    (ctx.GetDrawTarget()->GetBackendType() == BackendType::COREGRAPHICS)
+    ? Factory::CreateDrawTarget(BackendType::SKIA, maskSurfaceRect.Size(),
+                                SurfaceFormat::A8)
+    : ctx.GetDrawTarget()->CreateSimilarDrawTarget(maskSurfaceRect.Size(),
                                                    SurfaceFormat::A8);
   if (!maskDT || !maskDT->IsValid()) {
     paintResult.result = DrawResult::TEMPORARY_ERROR;
