@@ -1,5 +1,4 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * vim: sw=2 ts=2 et lcs=trail\:.,tab\:>~ :
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
@@ -23,11 +22,8 @@ private:
   nsresult SelfInit();
   void Start();
   void StartWatchdog();
-  void StartWriter();
 
   void UpdateHeartbeat(const char* aTopic);
-  void UpdateTelemetry();
-  void UpdateCrashReport(const char* aTopic);
 
   ~nsTerminator() {}
 
