@@ -675,7 +675,11 @@ nsUnknownContentTypeDialog.prototype = {
 
   // getPath:
   getPath: function (aFile) {
+#ifdef XP_MACOSX
+      return aFile.leafName || aFile.path;
+#else
     return aFile.path;
+#endif
   },
 
   // initAppAndSaveToDiskValues:
@@ -983,6 +987,12 @@ nsUnknownContentTypeDialog.prototype = {
         return file.getVersionInfoField("FileDescription");
       } catch (e) {}
     }
+#elifdef XP_MACOSX
+    if (file instanceof Components.interfaces.nsILocalFileMac) {
+      try {
+        return file.bundleDisplayName;
+      } catch (e) {}
+    }
 #endif
 
     return file.leafName;
